
/*
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.

 * < wxTutorial! Tutorial para el aprendizaje de las bibliotecas wxWidgets.>
 * Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
*/

#ifndef _NAVIGATOR_
#define _NAVIGATOR_

#ifdef __BORLANDC__
#pragma hdrstop
#endif

#include <wx/wx.h>
#include <wx/statline.h>
#include <wx/notebook.h>

#include "viewer.h"
#include "dimag.h"

class Viewer;

/**
 * @brief Definición de la navegación de la aplicación
 * por medio del formulario.
 *
 * @author Rosa María Durante Lerate
 * @note Parte del proyecto wxTutorial!
 */
class Navigator : public wxNotebook
{
 public:
  /**
   * @brief Constructor de la clase.
   * @param parent Puntero de tipo wxWindow siendo éste
   * el componente donde se ha llamado al diálogo.
   * @param p Posición del navegador en la aplicación.
   * @param s Tamaño del navegador en la aplicación.
   * @param style Estilos del navegador (wxNotebook styles).
   * @param name Nombre del componente.
   */
  Navigator(wxWindow* parent, const wxPoint& p, const wxSize& s, 
	    long style = 0, const wxString& name = wxString::FromUTF8("Navegador"));

  /**
   * @brief Función de asociación de dos clases (Navegator - Viewer).
   * @param v Puntero de tipo Viewer para crear la asociación.
   */
  void ViewerHtml(Viewer* v);

  /**
   * @brief Función que restaura el navegador.
   */
  void Restore();

 private:
 
  /**
   * @brief Definición de la pestaña de contenido.
   *
   * @author Rosa María Durante Lerate.
   * @note Parte del proyecto wxTutorial!
   */
  class PageContent : public wxNotebookPage
  {
  public:
    /**
     * @brief Constructor de la clase.
     * @param parent Puntero de tipo wxWindow siendo éste
     * el componente donde se ha llamado al diálogo.
     * @param title Título de la pestaña.
     */
    PageContent(Navigator* parent, const wxString& title);

    /**
     * @brief Función que restaura la página de contenido.
     */
    void Restore();
    
    /**
     * @brief Función que define el comportamiento del 
     * evento que se produce al cambiar de capítulo.
     * @param event Evento producido en la aplicación.
     */
    void OnChangeChapter(wxCommandEvent& event);

    /**
     * @brief Función que define el comportamiento del 
     * evento que se produce al cambiar de subcapítulo.
     * @param event Evento producido en la aplicación.
     */
    void OnChangeSubChapter(wxCommandEvent& event);
    
    /**
     * @brief Función que define el comportamiento del
     * evento que se produce al pulsar el botón para pasar
     * hacia atrás un subcapítulo.
     * @param event Evento producido en la aplicación.
     */
    void OnClickLastSubChapter(wxCommandEvent& event);

    /**
     * @brief Función que define el comportamiento del
     * evento que se produce al pulsar el botón para pasar
     * hacia delante un subcapítulo.
     * @param event Evento producido en la aplicación.
     */
    void OnClickNextSubChapter(wxCommandEvent& event);

    /**
     * @brief Función que define el comportamiento del
     * evento que se produce al pulsar el botón para pasar
     * hacia atrás un capítulo.
     * @param event Evento producido en la aplicación.
     */
    void OnClickLastChapter(wxCommandEvent& event);
    
    /**
     * @brief Función que define el comportamiento del 
     * evento que se produce al pulsar el botón para pasar
     * hacia delante un capítulo.
     * @param event Evento producido en la aplicación.
     */
    void OnClickNextChapter(wxCommandEvent& event);

  private:
    
    void ChangeChapter(void);
    void ChangeSubChapter(void);

    Navigator *parent;
    
    wxStaticText *labelchapter;
    wxStaticText *labelsubchapter;
    wxComboBox *chapter;
    wxComboBox *subchapter;

    wxStaticBox *buttonsbox;  
    wxBitmapButton *lastsubchapter;
    wxBitmapButton *nextsubchapter;
    wxBitmapButton *lastchapter;
    wxBitmapButton *nextchapter;

    DECLARE_EVENT_TABLE()
  };

  /**
   * @brief Definición de la pestaña de ejemplos.
   *
   * @author Rosa María Durante Lerate.
   * @note Parte del proyecto wxTutorial!
   */
  class PageExample : public wxNotebookPage
  {
  public:
    /**
     * @brief Constructor de la clase.
     * @param parent Puntero de tipo wxWindow siendo éste
     * el componente donde se ha llamado al diálogo.
     * @param title Título de la pestaña.
     */
    PageExample(Navigator* parent, const wxString& title);
    
    /**
     * @brief Función que restaura la página de ejemplo.
     */
    void Restore();

    /**
     * @brief Función que define el comportamiento del
     * evento que se produce cuando se cambie el ejemplo.
     * @param event Evento producido en la aplicación.
     */
    void OnChangeChapter(wxCommandEvent& event);

    /**
     * @brief Función que define el comportamiento del
     * evento que se produce al seleccionar otro fichero.
     * @param event Evento producido en la aplicación.
     */
    void OnChangeFile(wxCommandEvent& event);

    /**
     * @brief Función que define el comportamiento del 
     * evento que se produce al pulsar el botón de descarga.
     * @param event Evento producido en la aplicación.
     */
    void OnDownload(wxCommandEvent& event);
    
    /**
     * @brief Función que define el comportamiento del
     * evento que se produce al pulsar el botón de imágenes.
     * @param event Evento producido en la aplicación.
     */
    void OnShowPicture(wxCommandEvent& event);
    
  private:
    
    Navigator *parent;

    wxStaticText *labelexample;
    wxStaticText *labelfile;
    wxComboBox *example;
    
    wxListBox *file;

    wxBitmapButton *view;
    wxBitmapButton *download;

    DialogImage *dialogimage;

    DECLARE_EVENT_TABLE()
  };
  
  Viewer* view;

  PageContent *mainpage;
  PageExample *secpage;
};

#endif
